@@ -4,42 +4,42 @@
 <context>
     <name>DefaultModel</name>
     <message>
-        <location filename="../default_model.cpp" line="49"/>
+        <location filename="../default_model.cpp" line="51"/>
         <source>Command</source>
         <translation>Parancs</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="50"/>
+        <location filename="../default_model.cpp" line="52"/>
         <source>DBus call</source>
         <translation>DBus hívás</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="51"/>
+        <location filename="../default_model.cpp" line="53"/>
         <source>Client</source>
         <translation>Kliens</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="141"/>
+        <location filename="../default_model.cpp" line="143"/>
         <source>Id</source>
-        <translation></translation>
+        <translation>Azonosító</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="144"/>
+        <location filename="../default_model.cpp" line="146"/>
         <source>Shortcut</source>
         <translation>Gyorsbillentyű</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="147"/>
+        <location filename="../default_model.cpp" line="149"/>
         <source>Description</source>
         <translation>Leírás</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="150"/>
+        <location filename="../default_model.cpp" line="152"/>
         <source>Type</source>
         <translation>Típus</translation>
     </message>
     <message>
-        <location filename="../default_model.cpp" line="153"/>
+        <location filename="../default_model.cpp" line="155"/>
         <source>Info</source>
         <translation>Információ</translation>
     </message>
@@ -112,7 +112,7 @@
     <message>
         <location filename="../main_window.ui" line="14"/>
         <source>Global Actions Manager</source>
-        <translation>Általános művelet kezelő</translation>
+        <translation>Általános műveletkezelő</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="55"/>
@@ -122,7 +122,7 @@
     <message>
         <location filename="../main_window.ui" line="65"/>
         <source>Remove</source>
-        <translation>Törlés</translation>
+        <translation>Eltávolítás</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="75"/>
@@ -137,27 +137,31 @@
     <message>
         <location filename="../main_window.ui" line="118"/>
         <source>Multiple actions behaviour:</source>
-        <translation>Több művelet viselkedése:</translation>
+        <translation>Viselkedés több műveletnél:</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="126"/>
         <source>First</source>
-        <translation>Első</translation>
+        <comment>globalkeys/config/multipleActions</comment>
+        <translation type="unfinished">Első</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="131"/>
         <source>Last</source>
-        <translation>Utolsó</translation>
+        <comment>globalkeys/config/multipleActions</comment>
+        <translation type="unfinished">Utolsó</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="136"/>
         <source>None</source>
-        <translation>Nincs</translation>
+        <comment>globalkeys/config/multipleActions</comment>
+        <translation type="unfinished">Egyik sem</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="141"/>
         <source>All</source>
-        <translation>Mind</translation>
+        <comment>globalkeys/config/multipleActions</comment>
+        <translation type="unfinished">Mind</translation>
     </message>
     <message>
         <location filename="../main_window.ui" line="166"/>
